"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Record = void 0;
const DEFAULT_VERIFICATION_RECORD_TTL = 1800; // 30 minutes
class Record {
    constructor(name, type, value, ttl = DEFAULT_VERIFICATION_RECORD_TTL) {
        this.name = name;
        this.type = type;
        this.value = value;
        this.ttl = ttl;
    }
    static forIdentity(domainName, token) {
        return new this(`_amazonses.${domainName}`, "TXT", `"${token}"`);
    }
    static forDKIM(domainName, token) {
        return new this(`${token}._domainkey.${domainName}`, "CNAME", `${token}.dkim.amazonses.com`);
    }
    action(type) {
        if (type === "DELETE") {
            return {
                Action: "DELETE",
                ResourceRecordSet: {
                    Name: this.name,
                    Type: this.type,
                },
            };
        }
        else {
            return {
                Action: type,
                ResourceRecordSet: {
                    Name: this.name,
                    Type: this.type,
                    ResourceRecords: [{
                            Value: this.value,
                        }],
                    TTL: this.ttl,
                },
            };
        }
    }
}
exports.Record = Record;
//# sourceMappingURL=record.js.map